@@ -35,10 +35,10 @@ any fail, then this user may not access that view.
 
 from django import template
 from django.conf import settings
-from django.core.urlresolvers import Resolver404
+from django.core.urlresolvers import Resolver404, reverse, resolve
+from django.utils.itercompat import is_iterable
 
 register = template.Library()
-from django.core.urlresolvers import reverse, resolve
 
 def get_callable_cells(function):
     """
@@ -105,7 +105,17 @@ class MenuItem(template.Node):
         self.template_file = template_file or 'menu/item.html'
         self.url = url
         self.text = text
-        self.classes = classes or ""
+        self.classes = classes if classes else ""
+        self.icons = []
+        if classes:
+            self.classes = classes
+            if 'icon:' in classes:
+                classes = classes.strip("\"'").split(' ')
+                for cl in list(classes):
+                    if cl.startswith('icon:'):
+                        self.icons.append(cl[5:])
+                        classes.remove(cl)
+                self.classes = '"' + " ".join(classes) +'"'
         self.nodelist = []
         
     def render(self, context):
@@ -141,7 +151,8 @@ class MenuItem(template.Node):
         context.render_context[self] = {
             'url': url,
             'text': text,
-            'classes': classes
+            'classes': classes,
+            'icons': self.icons
         }
         
         local = dict(context.render_context[self])
@@ -239,4 +250,6 @@ def base_menu_item(template="menu/item.html"):
     return inner
 
 register.tag('menu_item', base_menu_item())
-register.tag('li_menu_item', base_menu_item('menu/li-item.html'))
\ No newline at end of file
+register.tag('li_menu_item', base_menu_item('menu/li-item.html'))
+register.tag('button_menu_item', base_menu_item('menu/button-item.html'))
+register.tag('li_button_menu_item', base_menu_item('menu/li-button-item.html'))
\ No newline at end of file
